@@ -29,7 +29,11 @@
 #' display(s)
 #' @export
 display.easycormatrix <- function(object, format = "markdown", digits = 2, stars = TRUE, ...) {
-  print_md(x = object, digits = digits, stars = stars, ...)
+  if (format == "markdown") {
+    print_md(x = object, digits = digits, stars = stars, ...)
+  } else {
+    print_html(x = object, digits = digits, stars = stars, ...)
+  }
 }
 
 
@@ -37,8 +41,6 @@ display.easycormatrix <- function(object, format = "markdown", digits = 2, stars
 display.easycorrelation <- display.easycormatrix
 
 
-
-
 # Reexports models ------------------------
 
 #' @importFrom insight display
