@@ -13,6 +13,8 @@
 #' @return Description of the Mahalanobis distance.
 #'
 #' @examples
+#' library(correlation)
+#'
 #' distance_mahalanobis(iris[, 1:4])
 #' distance_mahalanobis(iris[, 1:4], robust = FALSE)
 #' @importFrom stats mahalanobis cov
@@ -32,7 +34,7 @@ distance_mahalanobis <- function(data, ci = 0.95, iterations = 1000, robust = TR
     }
     # Get summary
     d <- bayestestR::describe_posterior(as.data.frame(Ms), centrality = "median", ci = ci, test = "pd")
-    d <- d[c("Median", "CI_low", "CI_high")]
+    d <- as.data.frame(d[c("Median", "CI_low", "CI_high")])
     rownames(d) <- NULL
     names(d) <- c("Distance", "CI_low", "CI_high")
   } else {
